@@ -12,5 +12,9 @@ sudo useradd -u 1004 -g 1005 -c "Monitor system" -s /usr/bin/nologin -d /tmp -M
 echo "Copy system-backup.slice to /etc/systemd/system"
 
 if [ -f /usr/local/share/amt/system-backup.slice ]; then
-   cp /usr/local/share/amt/system-backup.slice /etc/systemd/system/
+   sudo cp /usr/local/share/amt/system-backup.slice /etc/systemd/system/
 fi
+
+echo "Add user monitor to journald group"
+
+sudo usermod -a -G systemd-journal monitor 
